@@ -1,5 +1,3 @@
-/* $Id: Client.cs 1177 2006-03-09 20:27:47Z snorp $ */
-
 /***
   This file is part of avahi.
 
@@ -35,7 +33,7 @@ namespace Avahi
         Found,
         Failure
     }
-    
+
     internal enum BrowserEvent {
         Added,
         Removed,
@@ -70,7 +68,7 @@ namespace Avahi
             this.error = error;
         }
     }
-    
+
     public enum Protocol {
         Unspecified = -1,
         IPv4 = 0,
@@ -83,7 +81,7 @@ namespace Avahi
         Running,
         Collision
     }
-    
+
     public enum ClientState {
         Registering = ServerState.Registering,
         Running = ServerState.Running,
@@ -117,7 +115,7 @@ namespace Avahi
         IgnoreUserConfig = 1,
         NoFail = 2
     }
-    
+
     public class Client : IDisposable
     {
         private IntPtr handle;
@@ -151,7 +149,7 @@ namespace Avahi
 
         [DllImport ("avahi-client")]
         private static extern int avahi_client_errno (IntPtr handle);
-        
+
         [DllImport ("avahi-common")]
         private static extern IntPtr avahi_simple_poll_new ();
 
@@ -192,7 +190,7 @@ namespace Avahi
         {
             get { return handle; }
         }
-        
+
         public string Version
         {
             get {
@@ -286,10 +284,15 @@ namespace Avahi
         public void Dispose ()
         {
             if (handle != IntPtr.Zero) {
-                avahi_client_free (handle);
-                avahi_simple_poll_quit (spoll);
-                avahi_simple_poll_free (spoll);
-                handle = IntPtr.Zero;
+                lock (this) {
+                    avahi_client_free (handle);
+                    handle = IntPtr.Zero;
+
+                    avahi_simple_poll_quit (spoll);
+                    Monitor.Wait (this);
+
+                    avahi_simple_poll_free (spoll);
+                }
             }
         }
 
@@ -321,7 +324,7 @@ namespace Avahi
             IntPtr namePtr = Stdlib.malloc ((ulong) len);
             IntPtr typePtr = Stdlib.malloc ((ulong) len);
             IntPtr domainPtr = Stdlib.malloc ((ulong) len);
-            
+
             int ret = avahi_service_name_split (Utility.StringToBytes (service), namePtr, len, typePtr, len,
                                                 domainPtr, len);
 
@@ -329,7 +332,7 @@ namespace Avahi
                 Utility.Free (namePtr);
                 Utility.Free (typePtr);
                 Utility.Free (domainPtr);
-                
+
                 name = null;
                 type = null;
                 domain = null;
@@ -352,7 +355,7 @@ namespace Avahi
             if (error != ErrorCode.Ok)
                 throw new ClientException (error);
         }
-        
+
         private void OnClientCallback (IntPtr client, ClientState state, IntPtr userData)
         {
             if (StateChanged != null)
@@ -370,6 +373,7 @@ namespace Avahi
             try {
                 lock (this) {
                     avahi_simple_poll_loop (spoll);
+                    Monitor.Pulse (this);
                 }
             } catch (Exception e) {
                 Console.Error.WriteLine ("Error in avahi-sharp event loop: " + e);
